@@ -221,6 +221,15 @@ def teststack(request, render, render_example_tilespec_and_transforms):
     yield stack
     render.run(renderapi.stack.delete_stack, stack)
 
+@pytest.fixture(scope="module")
+def teststack_loading(request, render, render_example_tilespec_and_transforms):
+    (tilespecs, tforms) = render_example_tilespec_and_transforms
+    stack = 'test_insert_loading'
+    r = render.run(renderapi.stack.create_stack, stack, force_resolution=True)
+    render.run(renderapi.client.import_tilespecs, stack, tilespecs,
+               sharedTransforms=tforms)
+    yield stack
+    render.run(renderapi.stack.delete_stack, stack)
 
 def test_stack_bounds(render, teststack):
     # check the stack bounds
@@ -314,6 +323,25 @@ def test_bb_image_options(render, teststack):
                   maxIntensity=255)
 
 
+def test_bb_renderparams(render, teststack):
+    zvalues = render.run(renderapi.stack.get_z_values_for_stack, teststack)
+    z = zvalues[0]
+    bounds = render.run(renderapi.stack.get_bounds_from_z, teststack, z)
+    width = (bounds['maxX'] - bounds['minX']) / 2
+    height = (bounds['maxY'] - bounds['minY']) / 2
+    x = bounds['minX'] + width / 4
+    y = bounds['minY'] + width / 4
+    scale = 0.25
+
+    rp = renderapi.image.get_bb_renderparams(
+        teststack, z, x, y, width, height, scale=scale, render=render)
+    assert int(rp['width'] * rp['scale']) == int(width * scale)
+    assert int(rp['height'] * rp['scale']) == int(height * scale)
+    assert int(rp['x']) == int(x)
+    assert int(rp['y']) == int(y)
+    assert len(rp['tileSpecs'])
+
+
 def test_tile_image(render, teststack, render_example_tilespec_and_transforms,
                     **kwargs):
     (tilespecs, tforms) = render_example_tilespec_and_transforms
@@ -337,6 +365,23 @@ def test_tile_image_options(render, teststack,
         scale=testscale, filter=True, normalizeForMatching=False)
 
 
+def test_tile_renderparams(render, teststack):
+    zvalues = render.run(renderapi.stack.get_z_values_for_stack, teststack)
+    z = zvalues[0]
+
+    tspecs = renderapi.tilespec.get_tile_specs_from_z(
+        teststack, z, render=render)
+    ts = tspecs[0]
+
+    rp = renderapi.image.get_tile_renderparams(
+        teststack, ts.tileId, render=render)
+    assert int(rp['x']) == int(ts.minX)
+    assert int(rp['y']) == int(ts.minY)
+    assert len(rp['tileSpecs']) == 1
+    assert rp['height'] - 1 == int(ts.maxY - ts.minY)
+    assert rp['width'] - 1 == int(ts.maxX - ts.minX)
+
+
 def test_section_image(render, teststack, **kwargs):
     zvalues = render.run(renderapi.stack.get_z_values_for_stack, teststack)
     z = zvalues[0]
@@ -358,6 +403,19 @@ def test_section_image_options(render, teststack):
                        maxTileSpecsToRender=50)
 
 
+def test_section_renderparams(render, teststack):
+    zvalues = render.run(renderapi.stack.get_z_values_for_stack, teststack)
+    z = zvalues[0]
+    tspecs = renderapi.tilespec.get_tile_specs_from_z(
+        teststack, z, render=render)
+
+    scalefactor = 0.05
+    rp = renderapi.image.get_section_renderparams(
+        teststack, z, scale=scalefactor, render=render)
+    assert len(rp['tileSpecs']) == len(tspecs)
+    assert rp['scale'] == scalefactor
+
+
 def fail_image_get(render, teststack, render_example_tilespec_and_transforms):
     with pytest.raises(KeyError):
         render.run(renderapi.image.get_tile_image_data, teststack,
@@ -415,12 +473,15 @@ def test_get_tile_specs_from_stack(render, teststack,
     assert len(ts) == len(tilespecs)
 
 
-def test_get_sectionId_for_z(render, teststack,
+def test_get_sectionId_for_z(render, teststack, teststack_loading,
                              render_example_tilespec_and_transforms):
     (tilespecs, tforms) = render_example_tilespec_and_transforms
     sectionId = render.run(
         renderapi.stack.get_sectionId_for_z, teststack, tilespecs[0].z)
     assert (sectionId == tilespecs[0].layout.sectionId)
+    sectionId = render.run(
+        renderapi.stack.get_sectionId_for_z, teststack_loading, tilespecs[0].z)
+    assert (sectionId == tilespecs[0].layout.sectionId)
 
 
 def test_get_resolvedtiles_from_z(render, teststack,
