@@ -474,6 +474,7 @@ def get_canvas_url_template(
         stack, filter=False, renderWithoutMask=False,
         normalizeForMatching=True, excludeTransformsAfterLast=None,
         excludeFirstTransformAndAllAfter=None, excludeAllTransforms=False,
+        channels=None,
         host=None, port=None, owner=None, project=None, client_script=None,
         render=None, **kwargs):
     """function for making a render-parameters url template for point matching
@@ -507,6 +508,11 @@ def get_canvas_url_template(
     excludeAllTransforms: bool
         alternative to normalizeForMatching which simply removes all transforms from the list.
         default=False
+    channels: str
+        list of channels and weights to render in the format [channel name], [channel name]__[weight] or
+        channel one name]__[weight]__ ... [channel n name]__[weight].
+        e.g., "DAPI" or "DAPI__0.9__TdTomato__0.1"
+        default = None
     """  # noqa: E501
     request_url = format_preamble(host, port, owner, project, stack)
     tile_base_url = request_url + "/tile"
@@ -534,6 +540,8 @@ def get_canvas_url_template(
             excludeFirstTransformAndAllAfter)
     if excludeAllTransforms:
         url_suffix += '&excludeAllTransforms=true'
+    if channels:
+        url_suffix += '&channels={}'.format(channels)
 
     canvas_url_template = "%s/{}/%s" % (tile_base_url,
                                         url_suffix)
@@ -551,6 +559,8 @@ def pointMatchClient(stack, collection, tile_pairs,
                      excludeTransformsAfterLast=None,
                      excludeAllTransforms=None,
                      excludeFirstTransformAndAllAfter=None,
+                     stackChannels=None,
+                     stack2Channels=None,
                      subprocess_mode=None,
                      host=None, port=None,
                      owner=None, project=None, client_script=None,
@@ -598,7 +608,13 @@ def pointMatchClient(stack, collection, tile_pairs,
         transforms that you had applied after it. default= None.
     excludeAllTransforms: bool
         alternative to normalizeForMatching which simply removes all transforms from the list.
-        default=False
+        default = False
+    stackChannels: str or None
+        If specified, option to select which channel is used for the stack.
+        default = None
+    stack2Channels: str or None
+        If specified, option to select which channel is used for stack2, if specified.
+        default = None
 
     """  # noqa: E501
     sift_options = (SiftPointMatchOptions(**kwargs) if sift_options is None
@@ -625,6 +641,7 @@ def pointMatchClient(stack, collection, tile_pairs,
         excludeTransformsAfterLast,
         excludeFirstTransformAndAllAfter,
         excludeAllTransforms,
+        channels=stackChannels,
         host=host,
         port=port,
         owner=owner,
@@ -640,6 +657,7 @@ def pointMatchClient(stack, collection, tile_pairs,
             excludeTransformsAfterLast,
             excludeFirstTransformAndAllAfter,
             excludeAllTransforms,
+            channels=stack2Channels,
             host=host,
             port=port,
             owner=owner,
@@ -647,7 +665,6 @@ def pointMatchClient(stack, collection, tile_pairs,
             client_script=client_script)
     else:
         canvas_url_template2 = canvas_url_template
-
     for tile1, tile2 in tile_pairs:
         argvs += [canvas_url_template.format(tile1),
                   canvas_url_template2.format(tile2)]
